==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebCore/svg/properties/SVGAnimatedString.cpp <==
/*
 * Copyright (C) 2024 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "SVGAnimatedString.h"

#include "NodeDocument.h"
#include "NodeInlines.h"
#include "SVGScriptElement.h"
#include "ScriptExecutionContext.h"
#include "TrustedType.h"

namespace WebCore {

ExceptionOr<void> SVGAnimatedString::setBaseVal(const StringOrTrustedScriptURL& baseVal)
{
    auto stringValueHolder = WTF::switchOn(baseVal,
        [&](const String& str) -> ExceptionOr<String> {
            SVGElement* el = contextElement();
            if (el && isScriptElement(*el) && m_isHrefProperty == IsHrefProperty::Yes)
                return trustedTypeCompliantString(TrustedType::TrustedScriptURL, *(contextElement()->document().scriptExecutionContext()), str, "SVGScriptElement href"_s);
            return String(str);
        },
        [](const RefPtr<TrustedScriptURL>& trustedScriptURL) -> ExceptionOr<String> {
            return trustedScriptURL->toString();
        }
    );
    if (stringValueHolder.hasException())
        return stringValueHolder.releaseException();

    return SVGAnimatedPrimitiveProperty<String>::setBaseVal(stringValueHolder.releaseReturnValue());
}
}

==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Source/WebCore/svg/properties/SVGAnimatedString.cpp <==
/*
 * Copyright (C) 2024 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "SVGAnimatedString.h"

#include "NodeDocument.h"
#include "NodeInlines.h"
#include "SVGScriptElement.h"
#include "ScriptExecutionContext.h"
#include "TrustedType.h"

namespace WebCore {

ExceptionOr<void> SVGAnimatedString::setBaseVal(const StringOrTrustedScriptURL& baseVal)
{
    auto stringValueHolder = WTF::switchOn(baseVal,
        [&](const String& str) -> ExceptionOr<String> {
            SVGElement* el = contextElement();
            if (el && isScriptElement(*el) && m_isHrefProperty == IsHrefProperty::Yes)
                return trustedTypeCompliantString(TrustedType::TrustedScriptURL, *contextElement()->scriptExecutionContext(), str, "SVGScriptElement href"_s);
            return String(str);
        },
        [](const RefPtr<TrustedScriptURL>& trustedScriptURL) -> ExceptionOr<String> {
            return trustedScriptURL->toString();
        }
    );
    if (stringValueHolder.hasException())
        return stringValueHolder.releaseException();

    return SVGAnimatedPrimitiveProperty<String>::setBaseVal(stringValueHolder.releaseReturnValue());
}
}
